<?php

use Illuminate\Http\Request;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\API\PlanController;
use App\Http\Controllers\API\DemoController;
use App\Http\Controllers\API\AuthController;
use App\Http\Controllers\API\MasterController;
use App\Http\Controllers\API\ArticleController;
use App\Http\Controllers\API\CommonController;
use App\Http\Controllers\API\EventController;
use App\Http\Controllers\API\TransactionController;

/*
|--------------------------------------------------------------------------
| API Routes
|--------------------------------------------------------------------------
|
| Here is where you can register API routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| is assigned the "api" middleware group. Enjoy building your API!
|
*/

Route::middleware('auth:sanctum')->get('/user', function (Request $request) {
    return $request->user();
});

Route::post('/login', [AuthController::class, 'login']);
Route::post('/register', [AuthController::class, 'register']);
Route::post('/logout', [AuthController::class, 'logout'])->middleware('auth:api');
Route::post('/social/login', [AuthController::class, 'socialLogin']);
Route::post('/forgot/password', [AuthController::class, 'forgotPassword']);
Route::post('/company-list', [MasterController::class, 'companyList'])->name('api.company.list');
Route::post('/interest-list', [MasterController::class, 'interestList'])->name('api.interest.list');

Route::get('/delete-user', function(){
    app('firebase.firestore')->database()->collection('chatList')->document('125')->delete();
});

Route::group(['middleware' => 'auth:api'], function () {
    Route::post('/category-list', [MasterController::class, 'categoryList'])->name('api.category.list');
    Route::post('/industry-list', [MasterController::class, 'industryList'])->name('api.industry.list');
    Route::post('/publisher-list', [MasterController::class, 'publisherList'])->name('api.publisher.list');
    Route::get('/media-list', [MasterController::class, 'mediaList'])->name('api.media.list');
    Route::get('/subscription-list', [MasterController::class, 'subscriptionList'])->name('api.subscription.list');

    Route::post('/non-subscribe-user-article-list', [ArticleController::class, 'nonSubscribeUserArticleList'])->name('api.non.subscribe.user.article.list');
    Route::post('/change-favorite', [ArticleController::class, 'changeFavorite'])->name('api.change.favorite');
    Route::post('/article-detail', [ArticleController::class, 'articleDetail'])->name('api.article.detail');
    Route::post('/subscribe-user-article-list', [ArticleController::class, 'subscribeUserArticleList'])->name('api.subscribe.user.article.list');
    Route::post('/favorite-article', [ArticleController::class, 'favoriteArticle'])->name('api.favorite.article');

    Route::post('/contact-us', [CommonController::class, 'contactUs'])->name('api.contact.us');
    Route::get('/about-us', [CommonController::class, 'aboutUs'])->name('api.about.us');

    Route::post('/event-list', [EventController::class, 'eventList'])->name('api.event.list');
    Route::post('/event-detail', [EventController::class, 'eventDetail'])->name('api.event.detail');
    Route::post('/event-mail-history', [EventController::class, 'eventMailHistory'])->name('api.event.mail.history');

    Route::post('/edit-profile', [AuthController::class, 'editProfile'])->name('api.edit.profile');
    Route::get('/profile', [AuthController::class, 'profileDetail'])->name('api.profile.detail');
    Route::post('/create-group-subscription', [CommonController::class, 'createGroupSubscription'])->name('api.create.group.subscription');

    Route::post('/spotlight-member-list', [CommonController::class, 'spotlightMemberList'])->name('api.spotlight.member.list');
    Route::post('/spotlight-member-detail', [CommonController::class, 'spotlightMemberDetail'])->name('api.spotlight.member.detail');

    Route::post('/chat-user-list', [CommonController::class, 'chatUserList'])->name('api.chat.user.list');
    Route::post('/payment', [TransactionController::class, 'payment'])->name('api.payment');
    Route::post('/add-friend', [CommonController::class, 'addFriend'])->name('api.add.friend');
    Route::post('/send-spotlight-mail', [CommonController::class, 'sendSpotLightMail'])->name('api.send.spotlight.mail');
    Route::post('/get-profile-image', [CommonController::class, 'getProfileImage'])->name('api.get.profile.image');
    
    Route::get('/transaction-list', [TransactionController::class, 'transactionList'])->name('api.transaction.list');
    Route::post('/transaction-detail', [TransactionController::class, 'transactionDetail'])->name('api.transaction.detail');
    Route::get('/cancel-subscription', [TransactionController::class, 'cancelSubscription'])->name('api.cancel.subscription');
    Route::post('/manage-device-token', [AuthController::class, 'manageDeviceToken'])->name('api.manage.device.token');

    Route::get('/article-notification-list', [ArticleController::class, 'articleNotificationList'])->name('api.article.notification.list');
    Route::post('/delete-article-notification', [ArticleController::class, 'deleteArticleNotification'])->name('api.delete.article.notification');

});
