<?php

use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Mail;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\DemoController;
use App\Http\Controllers\PlanController;
use App\Http\Controllers\UserController;
use App\Http\Controllers\EventController;
use App\Http\Controllers\VideoController;
use App\Http\Controllers\DigestController;
use App\Http\Controllers\ScriptController;
use App\Http\Controllers\AboutUsController;
use App\Http\Controllers\AppUserController;
use App\Http\Controllers\CompanyController;
use App\Http\Controllers\PublishController;
use App\Http\Controllers\WebHookController;
use App\Http\Controllers\API\AuthController;
use App\Http\Controllers\CategoryController;
use App\Http\Controllers\IndustryController;
use App\Http\Controllers\InterestController;
use App\Http\Controllers\ContactUsController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\TransactionController;
use App\Http\Controllers\SubscriptionController;
use App\Http\Controllers\ForgotPasswordController;
use App\Http\Controllers\SpotlightMemberController;
use App\Http\Controllers\GroupSubscriptionController;
use App\Http\Controllers\GroupSubscriptionTransactionController;
/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider within a group which
| contains the "web" middleware group. Now create something great!
|
*/

Route::get('/', function () {
    return redirect()->route('login');
});
Route::get('register-user', [AuthController::class, 'registerGet'])->name('register-user');

Route::get('/send-email', function () {
    Mail::send('mails.example', [], function ($message) {
        $message->from('info@luxurycouncil.com', 'Testing From Email Address')->to('amishakarmaln@gmail.com', 'Amisha')->to('pallavi@emphatictechnologies.com', 'Pallavi')->cc('monil.vaywala@gmail.com')->subject('Contact Us');
    });
});
Route::post('login-submit', [LoginController::class, 'loginSubmit'])->name('login-submit');
Route::get('forget-password', [ForgotPasswordController::class, 'showForgetPasswordForm'])->name('forget.password.get');
Route::post('forget-password', [ForgotPasswordController::class, 'submitForgetPasswordForm'])->name('forget.password.post');
Route::get('reset-password/{token}', [ForgotPasswordController::class, 'showResetPasswordForm'])->name('reset.password.get');
Route::post('reset-password', [ForgotPasswordController::class, 'submitResetPasswordForm'])->name('reset.password.post');
Route::get('app-reset-password/{token}', [ForgotPasswordController::class, 'showAppResetPasswordForm'])->name('app.reset.password.get');
Route::post('app-reset-password', [ForgotPasswordController::class, 'submitAppResetPasswordForm'])->name('app.reset.password.post');
Route::post('/webhook-subscription', [WebHookController::class, 'subscription'])->name('webhook.subscription');
Route::post('/webhook-transaction', [WebHookController::class, 'transaction'])->name('webhook.transaction');

Auth::routes();

Route::group(['middleware' => 'api'], function () {
    Route::get('/transaction-user-list', [TransactionController::class, 'appUserTracation'])->name('transaction.user.list');
    Route::get('app-user-edit/{id}', [AppUserController::class, 'edit'])->name('app-user-edit.edit');
    Route::get('/subscription-list-user', [SubscriptionController::class, 'userList'])->name('subscription.user-list');
    Route::get('/add-subscription/{subscription_id}', [SubscriptionController::class, 'addUserSubscription'])->name('add-subscription');
    Route::post('/transaction-payment', [TransactionController::class, 'payment'])->name('transaction.payment');
    Route::put('app-user-update/{id}', [AppUserController::class, 'update'])->name('app-user-update.update');
    

});

Route::group(['middleware' => 'auth'], function () {
Route::get('/home', [App\Http\Controllers\HomeController::class, 'index'])->name('home');

Route::get('/article-form', [PlanController::class, 'index'])->name('articles.form');
Route::get('/article-list', [PlanController::class, 'list'])->name('articles.list');
Route::post('/article-ajax-list', [PlanController::class, 'ajaxList'])->name('articles.ajaxList');
Route::post('/add-article-form', [PlanController::class, 'addArticle'])->name('articles.add');
Route::get('/article-edit/{id}', [PlanController::class, 'editArticle'])->name('articles.edit');
Route::post('/article-update', [PlanController::class, 'updateArticle'])->name('articles.update');
Route::get('/article-delete/{id}', [PlanController::class, 'deleteArticle'])->name('articles.delete');

Route::get('/company-list', [CompanyController::class, 'list'])->name('company.list');
Route::get('/company-form/{id}', [CompanyController::class, 'index'])->name('company.form');
Route::post('/add-company-form', [CompanyController::class, 'addCompany'])->name('company.add');
Route::get('/company-delete/{id}', [CompanyController::class, 'deleteCompany'])->name('company.delete');
Route::post('/company-ajax-list', [CompanyController::class, 'ajaxList'])->name('company.ajaxList');

Route::get('/industry-list', [IndustryController::class, 'list'])->name('industry.list');
Route::any('/industry-form/{id?}', [IndustryController::class, 'index'])->name('industry.form');
Route::post('/add-industry-form', [IndustryController::class, 'addIndustry'])->name('industry.add');
Route::get('/industry-delete/{id}', [IndustryController::class, 'deleteIndustry'])->name('industry.delete');
Route::post('/industry-ajax-list', [IndustryController::class, 'ajaxList'])->name('industry.ajaxList');

Route::get('/category-list', [CategoryController::class, 'list'])->name('category.list');
Route::any('/category-form/{id?}', [CategoryController::class, 'index'])->name('category.form');
Route::any('/add-category-form', [CategoryController::class, 'addCategory'])->name('category.add');
Route::get('/category-delete/{id}', [CategoryController::class, 'deleteCategory'])->name('category.delete');
Route::post('/category-ajax-list', [CategoryController::class, 'ajaxList'])->name('category.ajaxList');

Route::get('/interest-list', [InterestController::class, 'list'])->name('interest.list');
Route::any('/interest-form/{id?}', [InterestController::class, 'index'])->name('interest.form');
Route::any('/add-interest-form', [InterestController::class, 'addInterest'])->name('interest.add');
Route::get('/interest-delete/{id}', [InterestController::class, 'deleteInterest'])->name('interest.delete');
Route::post('/interest-ajax-list', [InterestController::class, 'ajaxList'])->name('interest.ajaxList');

Route::get('/publish-list', [PublishController::class, 'list'])->name('publish.list');
Route::any('/publish-form/{id?}', [PublishController::class, 'index'])->name('publish.form');
Route::any('/add-publish-form', [PublishController::class, 'addPublish'])->name('publish.add');
Route::get('/publisher-delete/{id}', [PublishController::class, 'deletePublisher'])->name('publisher.delete');
Route::post('/publisher-ajax-list', [PublishController::class, 'ajaxList'])->name('publisher.ajaxList');

Route::get('/demo-list', [DemoController::class, 'demoList'])->name('demo_list');
Route::get('/demo-form', [DemoController::class, 'showDemoForm'])->name('demo_form');

Route::any('/ajax-request', [PlanController::class,'handleRequest'])->name('ajax.request');

Route::get('/video-upload', [ VideoController::class, 'getVideoUploadForm' ])->name('video.upload');
Route::post('/video-upload', [ VideoController::class, 'uploadVideo' ])->name('store.video');

Route::get('/subscription-list', [SubscriptionController::class, 'list'])->name('subscription.list');
Route::any('/subscription-form/{id?}', [SubscriptionController::class, 'index'])->name('subscription.form');
Route::any('/add-subscription-form', [SubscriptionController::class, 'addSubscription'])->name('subscription.add');
Route::get('/subscription-delete/{id}', [SubscriptionController::class, 'deleteSubscription'])->name('subscription.delete');
Route::post('/subscription-ajax-list', [SubscriptionController::class, 'ajaxList'])->name('subscription.ajax.list');


Route::get('/contact-us', [ ContactUsController::class, 'getContactUs' ])->name('contact.us');
Route::post('/contact-us-upload', [ ContactUsController::class, 'ContactUsUpload' ])->name('store.contactus');

Route::get('/about-us', [ AboutUsController::class, 'getContactUs' ])->name('about.us');
Route::post('/about-us-upload', [ AboutUsController::class, 'AboutUsUpload' ])->name('store.aboutus');

Route::get('/digest-settings', [ DigestController::class, 'getContactUs' ])->name('digest.settings');
Route::post('/digest-settings-upload', [ DigestController::class, 'ContactUsUpload' ])->name('store.digest');

Route::get('/users-list', [UserController::class, 'list'])->name('users.list');
Route::post('/user-ajax-list', [UserController::class, 'ajaxList'])->name('user.ajax.list');
Route::any('/users-form/{id?}', [UserController::class, 'index'])->name('users.form');
Route::any('/add-users-form', [UserController::class, 'addUser'])->name('users.add');
Route::get('/users-delete/{id}', [UserController::class, 'deleteUser'])->name('users.delete');

Route::resource('spotlight', SpotlightMemberController::class, [ 'names' => ['index' =>'spotlight.index', 'create' =>'spotlight.create','store' =>'spotlight.store','edit' =>'spotlight.edit','update' =>'spotlight.update','destroy' =>'spotlight.destroy']]);
Route::post('/spotlight-member-ajax-list', [SpotlightMemberController::class, 'ajaxList'])->name('spotlight.member.ajax.list');

Route::resource('event', EventController::class, [ 'names' => ['index' =>'event.index', 'create' =>'event.create','store' =>'event.store','edit' =>'event.edit','update' =>'event.update','destroy' =>'event.destroy']]);
Route::post('/event-ajax-list', [EventController::class, 'ajaxList'])->name('event.ajax.list');
Route::post('/event-preview-ajax', [EventController::class, 'preview'])->name('event.preview.ajax');
Route::post('/event-send-mail-overlay-ajax', [EventController::class, 'openOverlay'])->name('event.send.mail.overlay.ajax');
Route::post('/event-send-mail-ajax', [EventController::class, 'sendMail'])->name('event.send.mail.ajax');
Route::post('/event-search-app-user-ajax', [EventController::class, 'searchAppUser'])->name('event.search.app.user.ajax');

Route::get('app-user/index', [AppUserController::class, 'index'])->name('app.user.index');
Route::resource('app-user', AppUserController::class, [ 'names' => ['create' =>'app.user.create','store' =>'app.user.store','edit' =>'app.user.edit','update' =>'app.user.update','destroy' =>'app.user.destroy']]);
Route::post('/app-user-ajax-list', [AppUserController::class, 'ajaxList'])->name('app.user.ajax.list');


Route::resource('group-subscription', GroupSubscriptionController::class, [ 'names' => ['index' =>'group.subscription.index', 'create' =>'group.subscription.create','store' =>'group.subscription.store','edit' =>'group.subscription.edit','update' =>'group.subscription.update','destroy' =>'group.subscription.destroy']]);
Route::post('/group-subscription-ajax-list', [GroupSubscriptionController::class, 'ajaxList'])->name('group.subscription.ajax.list');
Route::post('/import-user-overlay-ajax', [GroupSubscriptionController::class, 'openOverlay'])->name('import.user.overlay.ajax');
Route::post('/import-user-ajax', [GroupSubscriptionController::class, 'importUser'])->name('import.user');

Route::resource('transaction', TransactionController::class, [ 'names' => ['index' =>'transaction.index']]);
Route::post('/transaction-ajax-list', [TransactionController::class, 'ajaxList'])->name('transaction.ajax.list');
// Route::get('/transaction-user-list', [TransactionController::class, 'appUserTracation'])->name('transaction.user.list');

Route::post('/group-subscription-purchase', [GroupSubscriptionController::class, 'purchase'])->name('group.subscription.purchase');
Route::post('/group-subscription-purchase-ajax', [GroupSubscriptionController::class, 'openPurchaseOverlay'])->name('group.subscription.purchase.ajax');

Route::resource('group-transaction', GroupSubscriptionTransactionController::class, [ 'names' => ['index' =>'group.transaction.index']]);
Route::post('/group-transaction-ajax-list', [GroupSubscriptionTransactionController::class, 'ajaxList'])->name('group.transaction.ajax.list');

Route::post('/user-name-list', [TransactionController::class, 'userList'])->name('ajax.user.list');
Route::post('/subscription-exists', [GroupSubscriptionController::class, 'subscriptionExists'])->name('subscription.exists');

Route::group(['prefix' => 'script'], function () {
    Route::get('/update-thumbnail', [ScriptController::class, 'updateThumbnail'])->name('update.thumbnail');
});
});
